==> correo-1.0.0.tgz: package/README.md <==
<h1 align="center">
  <br>
  <a href="http://www.amitmerchant.com/correo"><img src="res/correo.png" alt="Markdownify" width="200"></a>
  <br>
  Correo
  <br>
</h1>

<h4 align="center">A menubar/taskbar Gmail App based on <a href="http://electron.atom.io" target="_blank">Electron</a>.</h4>

**Windows**

![screenshot](res/screenshot.png)

### Install

`npm install correo`

### License

>The [MIT license](https://opensource.org/licenses/MIT) (MIT)
>
>Copyright (c) [Amit Merchant](https://www.amitmerchant.com/)
>
>Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
>
>The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
>
>THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

==> correo-1.0.1.tgz: package/README.md <==
<h1 align="center">
  <br>
  <a href="http://www.amitmerchant.com/correo"><img src="https://raw.githubusercontent.com/amitmerchant1990/correo/master/res/correo.png" alt="Markdownify" width="200"></a>
  <br>
  Correo
  <br>
</h1>

<h4 align="center">A menubar/taskbar Gmail App based on <a href="http://electron.atom.io" target="_blank">Electron</a>.</h4>

**Windows**

![screenshot](https://raw.githubusercontent.com/amitmerchant1990/correo/master/res/screenshot.png)

### Install

`npm install correo`

### License

>The [MIT license](https://opensource.org/licenses/MIT) (MIT)
>
>Copyright (c) [Amit Merchant](https://www.amitmerchant.com/)
>
>Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
>
>The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
>
>THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
